import _extends from "@babel/runtime/helpers/esm/extends";
import optimizelySDK from '@optimizely/optimizely-sdk';
import integrations from './integrations';
var DEFAULT_OPTIONS = {
  autoUpdate: true,
  updateInterval: 60 * 1000,
  // 60 seconds in milliseconds
  logLevel: 'info'
};
var DEFAULT_TIMEOUT = 500;

var OptimizelyAdapter = /*#__PURE__*/function () {
  /**
   * @constructor
   * @param {object} param
   * @param {object} param.optimizely OptimizelyInstance returned by createOptimizelyInstance method
   * @param {string=} param.userId
   * @param {object} param.activeIntegrations segment activated by default
   */
  function OptimizelyAdapter(_ref) {
    var optimizely = _ref.optimizely,
        userId = _ref.userId,
        _ref$activeIntegratio = _ref.activeIntegrations,
        activeIntegrations = _ref$activeIntegratio === void 0 ? {
      segment: true
    } : _ref$activeIntegratio;

    if (!optimizely) {
      throw new Error('optimizely instance is mandatory to use OptimizelyAdapter');
    }

    this._optimizely = optimizely;
    this._userId = userId == null ? void 0 : userId.toString();

    if (this._isActivated()) {
      integrations.forEach(function (integration) {
        return integration({
          activeIntegrations: activeIntegrations,
          optimizelyInstance: optimizely
        });
      });
    }
  }
  /**
   * @param {object} param
   * @param {string} param.sdkKey
   * @param {object} [param.options] https://docs.developers.optimizely.com/full-stack/docs/initialize-sdk-javascript-node
   */


  OptimizelyAdapter.createOptimizelyInstance = function createOptimizelyInstance(_ref2) {
    var optionParameter = _ref2.options,
        sdkKey = _ref2.sdkKey;

    var options = _extends({}, DEFAULT_OPTIONS, optionParameter);

    optimizelySDK.setLogLevel(options.logLevel);
    optimizelySDK.setLogger(optimizelySDK.logging.createLogger());
    var optimizelyInstance = optimizelySDK.createInstance({
      sdkKey: sdkKey,
      datafileOptions: options
    });
    return optimizelyInstance;
  };

  var _proto = OptimizelyAdapter.prototype;

  _proto._isActivated = function _isActivated() {
    if (!this._userId) return false;
    return true;
  };

  _proto.getEnabledFeatures = function getEnabledFeatures(_temp) {
    var _ref3 = _temp === void 0 ? {} : _temp,
        attributes = _ref3.attributes;

    return this._optimizely.getEnabledFeatures(this._userId, attributes);
  }
  /**
   * Activates an A/B test for the specified user to start an experiment: determines whether they qualify for the experiment,
   * buckets a qualified user into a variation, and sends an impression event to Optimizely.
   * More info: https://docs.developers.optimizely.com/full-stack/docs/activate-javascript-node
   * @param {Object} params
   * @param {string} params.name
   * @param {object} [params.attributes]
   * @returns {string} variation name
   */
  ;

  _proto.activateExperiment = function activateExperiment(_ref4) {
    var name = _ref4.name,
        attributes = _ref4.attributes;
    if (!this._isActivated()) return 'default';
    return this._optimizely.activate(name, this._userId, attributes);
  };

  _proto.onReady = function onReady() {
    var _this = this;

    return this._optimizely.onReady({
      timeout: DEFAULT_TIMEOUT
    }).then(function () {
      return _this._optimizely;
    });
  };

  return OptimizelyAdapter;
}();

export { OptimizelyAdapter as default };