import { useContext, useMemo } from 'react';
import PdeContext from '../contexts/PdeContext';
/**
 * Hook to use a experiment
 * @param {string} experimentName
 * @param {object} attributes
 * @return {{variation: string}}
 */

export default function useExperiment(experimentName, attributes) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useExperiment] sui-pde provider is required to work');
  var variation = useMemo(function () {
    var variationName;

    try {
      variationName = pde.activateExperiment({
        name: experimentName,
        attributes: attributes
      });
    } catch (error) {
      console.error(error);
      return 'default';
    }

    return variationName;
  }, [experimentName, pde, attributes]);
  return {
    variation: variation
  };
}